# Demos

Measure computational and statistical performance.

```bash
pip install "cappr[demos]"
```

In here, demos of text generation intentionally use custom post-processing functions to
attempt to squeeze the most out of text generation.

Thank you to the Refuel [autolabel](https://github.com/refuel-ai/autolabel/) team for
finding good classification tasks.
